@@ -25,6 +25,15 @@ class EnvironmentAPIKeyModel:
         )
 
 
+@dataclass
+class WebhookModel:
+    created_at: datetime
+    updated_at: datetime
+    url: str
+    secret: str
+    enabled: bool = True
+
+
 @dataclass
 class EnvironmentModel:
     id: int
@@ -35,12 +44,16 @@ class EnvironmentModel:
     segment_config: IntegrationModel = None
     mixpanel_config: IntegrationModel = None
     heap_config: IntegrationModel = None
+    dynatrace_config: IntegrationModel = None
+    webhooks: typing.List[WebhookModel] = field(default_factory=list)
 
     _INTEGRATION_ATTS = [
         "amplitude_config",
         "segment_config",
         "mixpanel_config",
         "heap_config",
+        "dynatrace_config",
+        "webhooks",
     ]
 
     @property
@@ -65,5 +78,6 @@ class EnvironmentModel:
                 integrations_data[integration_attr] = {
                     "base_url": integration_config.base_url,
                     "api_key": integration_config.api_key,
+                    "entity_selector": integration_config.entity_selector,
                 }
         return integrations_data
